@@ -7,10 +7,11 @@ from typing import Any, List, Mapping, Union
 
 import requests
 from airbyte_cdk.sources.declarative.decoders.decoder import Decoder
+from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class JsonDecoder(Decoder):
+class JsonDecoder(Decoder, JsonSchemaMixin):
     """
     Decoder strategy that returns the json-encoded content of a response, if any.
     """
