@@ -2,6 +2,7 @@
 # Copyright (c) 2022 Airbyte, Inc., all rights reserved.
 #
 
+import os
 from dataclasses import InitVar, dataclass
 from functools import lru_cache
 from typing import Any, Mapping, MutableMapping, Optional, Union
@@ -72,14 +73,14 @@ class HttpRequester(Requester, JsonSchemaMixin):
         return self.authenticator
 
     def get_url_base(self):
-        return self.url_base.eval(self.config)
+        return os.path.join(self.url_base.eval(self.config), "")
 
     def get_path(
         self, *, stream_state: Optional[StreamState], stream_slice: Optional[StreamSlice], next_page_token: Optional[Mapping[str, Any]]
     ) -> str:
         kwargs = {"stream_state": stream_state, "stream_slice": stream_slice, "next_page_token": next_page_token}
         path = self.path.eval(self.config, **kwargs)
-        return path
+        return path.strip("/")
 
     def get_method(self):
         return self._method
